==> owncloud-4.5.7.tgz: owncloud/apps/contacts/l10n/lb.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Fehler beim (de)aktivéieren vum Adressbuch.",
"id is not set." => "ID ass net gesat.",
"No ID provided" => "Keng ID uginn",
"Error setting checksum." => "Fehler beim setzen vun der Checksum.",
"No categories selected for deletion." => "Keng Kategorien fir ze läschen ausgewielt.",
"No address books found." => "Keen Adressbuch fonnt.",
"No contacts found." => "Keng Kontakter fonnt.",
"Cannot add empty property." => "Ka keng eidel Proprietéit bäisetzen.",
"Trying to add duplicate property: " => "Probéieren duebel Proprietéit bäi ze setzen:",
"Information about vCard is incorrect. Please reload the page." => "Informatioun iwwert vCard ass net richteg. Lued d'Säit wegl nei.",
"Missing ID" => "ID fehlt",
"No contact ID was submitted." => "Kontakt ID ass net mat geschéckt ginn.",
"Error reading contact photo." => "Fehler beim liesen vun der Kontakt Photo.",
"Error saving temporary file." => "Fehler beim späicheren vum temporäre Fichier.",
"The loading photo is not valid." => "Déi geluede Photo ass net gülteg.",
"Contact ID is missing." => "Kontakt ID fehlt.",
"File doesn't exist:" => "Fichier existéiert net:",
"Error loading image." => "Fehler beim lueden vum Bild.",
"No file was uploaded" => "Et ass kee Fichier ropgeluede ginn",
"Contacts" => "Kontakter",
"Error" => "Fehler",
"Result: " => "Resultat: ",
" imported, " => " importéiert, ",
"Download" => "Download",
"Edit" => "Editéieren",
"Delete" => "Läschen",
"Cancel" => "Ofbriechen",
"This is not your addressbook." => "Dat do ass net däin Adressbuch.",
"Contact could not be found." => "Konnt den Kontakt net fannen.",
"Work" => "Aarbecht",
"Home" => "Doheem",
"Mobile" => "GSM",
"Text" => "SMS",
"Voice" => "Voice",
"Message" => "Message",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internet",
"Birthday" => "Gebuertsdag",
"{name}'s Birthday" => "{name} säi Gebuertsdag",
"Contact" => "Kontakt",
"Add Contact" => "Kontakt bäisetzen",
"Close" => "Zoumaachen",
"Organization" => "Firma",
"Nickname" => "Spëtznumm",
"Enter nickname" => "Gëff e Spëtznumm an",
"dd-mm-yyyy" => "dd-mm-yyyy",
"Groups" => "Gruppen",
"Edit groups" => "Gruppen editéieren",
"Enter phone number" => "Telefonsnummer aginn",
"Delete phone number" => "Telefonsnummer läschen",
"View on map" => "Op da Kaart uweisen",
"Edit address details" => "Adress Detailer editéieren",
"Phone" => "Telefon",
"Email" => "Email",
"Address" => "Adress",
"Note" => "Note",
"Download contact" => "Kontakt eroflueden",
"Delete contact" => "Kontakt läschen",
"Type" => "Typ",
"PO Box" => "Postleetzuel",
"Extended" => "Erweidert",
"City" => "Staat",
"Region" => "Regioun",
"Zipcode" => "Postleetzuel",
"Country" => "Land",
"Addressbook" => "Adressbuch",
"Mr" => "M",
"Sir" => "Sir",
"Mrs" => "Mme",
"Dr" => "Dr",
"Given name" => "Virnumm",
"Additional names" => "Weider Nimm",
"Family name" => "Famillje Numm",
"Ph.D." => "Ph.D.",
"Jr." => "Jr.",
"Sn." => "Sn.",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressbicher ",
"New Address Book" => "Neit Adressbuch",
"Save" => "Späicheren"
);

==> owncloud-5.0.9.tgz: owncloud/apps/contacts/l10n/lb.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Fehler beim (de)aktivéieren vum Adressbuch.",
"id is not set." => "ID ass net gesat.",
"No ID provided" => "Keng ID uginn",
"Error setting checksum." => "Fehler beim setzen vun der Checksum.",
"No categories selected for deletion." => "Keng Kategorien fir ze läschen ausgewielt.",
"No address books found." => "Keen Adressbuch fonnt.",
"No contacts found." => "Keng Kontakter fonnt.",
"Information about vCard is incorrect. Please reload the page." => "Informatioun iwwert vCard ass net richteg. Lued d'Säit wegl nei.",
"No contact ID was submitted." => "Kontakt ID ass net mat geschéckt ginn.",
"Error reading contact photo." => "Fehler beim liesen vun der Kontakt Photo.",
"Error saving temporary file." => "Fehler beim späicheren vum temporäre Fichier.",
"The loading photo is not valid." => "Déi geluede Photo ass net gülteg.",
"Contact ID is missing." => "Kontakt ID fehlt.",
"File doesn't exist:" => "Fichier existéiert net:",
"Error loading image." => "Fehler beim lueden vum Bild.",
"There is no error, the file uploaded with success" => "Keen Feeler, Datei ass komplett ropgelueden ginn",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Déi ropgelueden Datei ass méi grouss wei d'upload_max_filesize Eegenschaft an der php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
"The uploaded file was only partially uploaded" => "Déi ropgelueden Datei ass nëmmen hallef ropgelueden ginn",
"No file was uploaded" => "Et ass kee Fichier ropgeluede ginn",
"Missing a temporary folder" => "Et feelt en temporären Dossier",
"Contacts" => "Kontakter",
"Error" => "Fehler",
"Unable to upload your file as it is a directory or has 0 bytes" => "Kann deng Datei net eroplueden well et en Dossier ass oder 0 byte grouss ass.",
"Upload Error" => "Fehler beim eroplueden",
"Result: " => "Resultat: ",
" imported, " => " importéiert, ",
"Download" => "Download",
"Edit" => "Editéieren",
"Delete" => "Läschen",
"Cancel" => "Ofbriechen",
"Work" => "Aarbecht",
"Home" => "Doheem",
"Other" => "Aner",
"Mobile" => "GSM",
"Text" => "SMS",
"Voice" => "Voice",
"Message" => "Message",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internet",
"{name}'s Birthday" => "{name} säi Gebuertsdag",
"Contact" => "Kontakt",
"Settings" => "Astellungen",
"Import" => "Import",
"OK" => "OK",
"Groups" => "Gruppen",
"Close" => "Zoumaachen",
"Additional names" => "Weider Nimm",
"Nickname" => "Spëtznumm",
"Enter nickname" => "Gëff e Spëtznumm an",
"Title" => "Titel",
"Organization" => "Firma",
"Birthday" => "Gebuertsdag",
"Add" => "Dobäisetzen",
"Phone" => "Telefon",
"Email" => "Email",
"Address" => "Adress",
"Note" => "Note",
"Delete contact" => "Kontakt läschen",
"Enter phone number" => "Telefonsnummer aginn",
"Delete phone number" => "Telefonsnummer läschen",
"View on map" => "Op da Kaart uweisen",
"City" => "Staat",
"Country" => "Land",
"Share" => "Deelen",
"Export" => "Export",
"more info" => "méi Informatiounen",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressbicher ",
"New Address Book" => "Neit Adressbuch",
"Name" => "Numm",
"Save" => "Späicheren"
);
